@@ -3,7 +3,7 @@ symsolve <- function(Asym, Bmat)
   #  solves the system ASYM X = BMAT for X where ASYM is symmetric
   #  returns X
   n <- ncol(Asym)
-  if (max(abs(Asym)) == 0) stop("Asym is all zeros.")
+  if (any(is.na(Asym))) stop("Asym has NA values.")
   if (max(abs(Asym-t(Asym)))/max(abs(Asym)) > 1e-10) {
     stop('Argument not symmetric.')
   } else {
